"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const github_profile_status_1 = require("github-profile-status");
const sourceProvider_1 = require("./sources/sourceProvider");
const utils_1 = require("./utils");
var Event;
(function (Event) {
    Event["StatusUpdated"] = "status-updated";
    Event["StatusCleared"] = "status-cleared";
    Event["Error"] = "error";
})(Event || (Event = {}));
class NowPlayingMonitor extends utils_1.SimpleEventEmitter {
    constructor(options) {
        super();
        this.options = options;
        this.init();
    }
    set source(source) {
        this.sourceProvider = source;
        this.sourceProvider
            .on(sourceProvider_1.NowPlayingSourceProvider.Events.TrackChanged, this.updateStatus.bind(this))
            .on(sourceProvider_1.NowPlayingSourceProvider.Events.TrackStopped, this.clearStatus.bind(this))
            .on(sourceProvider_1.NowPlayingSourceProvider.Events.Error, this.emit.bind(this, Event.Error));
    }
    init() {
        this.profileStatus = new github_profile_status_1.GitHubProfileStatus({
            sessionCookie: this.options.sessionCookie,
        });
    }
    updateStatus(track) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield this.profileStatus.set({
                    emoji: ':musical_note:',
                    message: `is listening to "${track.title}" by ${track.artist}`,
                });
                this.emit(Event.StatusUpdated, track);
            }
            catch (error) {
                this.emit(Event.Error, error);
            }
        });
    }
    clearStatus() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield this.profileStatus.clear();
                this.emit(Event.StatusCleared);
            }
            catch (error) {
                this.emit(Event.Error, error);
            }
        });
    }
}
NowPlayingMonitor.Events = Event;
exports.NowPlayingMonitor = NowPlayingMonitor;
