"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../utils");
var Event;
(function (Event) {
    Event["Error"] = "error";
    Event["TrackChanged"] = "track-changed";
    Event["TrackStopped"] = "track-stopped";
})(Event || (Event = {}));
class NowPlayingSourceProvider extends utils_1.SimpleEventEmitter {
    constructor(options) {
        super();
        this.options = options;
        this.lastTrack = null;
        this.updateFrequency = options.updateFrequency;
        this.checkNowPlaying();
    }
    getNowPlaying() {
        return __awaiter(this, void 0, void 0, function* () {
            throw new Error('Method not implemented');
        });
    }
    /**
     * @todo add track-checked event
     */
    check() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const result = yield this.getNowPlaying();
                return result;
            }
            catch (error) {
                this.emit(NowPlayingSourceProvider.Events.Error, error);
                return null;
            }
        });
    }
    checkNowPlaying() {
        return __awaiter(this, void 0, void 0, function* () {
            const track = yield this.check();
            if (this.hasTrackChanged(track)) {
                this.lastTrack = track;
                if (track) {
                    this.emit(Event.TrackChanged, track);
                }
                else {
                    this.emit(Event.TrackStopped);
                }
            }
            setTimeout(this.checkNowPlaying.bind(this), this.updateFrequency);
        });
    }
    hasTrackChanged(track) {
        if (this.lastTrack && track) {
            for (const key in track) {
                if (track[key] !== this.lastTrack[key]) {
                    return true;
                }
            }
            return false;
        }
        return this.lastTrack !== track;
    }
}
NowPlayingSourceProvider.Events = Event;
exports.NowPlayingSourceProvider = NowPlayingSourceProvider;
